"""
    created 24.03.2022 by Jens Diemer <opensource@jensdiemer.de>
    :copyleft: 2022 by the django-fritzconnection team, see AUTHORS for more details.
    :license: GNU GPL v3 or above, see LICENSE for more details.
"""

__version__ = "0.0.2.rc0"
