# Generated by Django 4.0.3 on 2022-04-01 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djfritz', '0002_hostmodel_ip_v4_hostmodel_ip_v6'),
    ]

    operations = [
        migrations.AddField(
            model_name='hostmodel',
            name='wan_access',
            field=models.CharField(choices=[('granted', 'granted'), ('denied', 'denied'), ('error', 'error'), ('unknown', 'unknown')], default='unknown', editable=False, help_text='HostModel.wan_access.help_text', max_length=7, verbose_name='HostModel.wan_access.verbose_name'),
        ),
    ]
