{% extends "reversion/change_list.html" %}
{% load i18n admin_urls %}


{% block object-tools-items %}
    {% if not is_popup and has_add_permission and has_change_permission %}
        <li><a href="{% url opts|admin_urlname:'update_hosts' %}" >{% trans "Update all hosts" %}</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}