{% extends "admin/base.html" %}
{% load i18n static djfritz %}

{% block extrahead %}{{ block.super }}
    <meta name="google" content="notranslate">
    <meta name="robots" content="noindex,nofollow" />
    <link rel="stylesheet" type="text/css" href="{% static 'djfritz.css' %}">
{% endblock %}

{% block title %}{{ title }} | django-fritzconnection {{ djfritz_version_string }}{% endblock %}

{% block branding %}
<h1 id="site-name">
    <a href="{% url 'admin:index' %}">django-fritzconnection {{ djfritz_version_string }}</a>
</h1>
{% endblock %}

{% block usertools %}
    {% fritzbox_link %}
    {{ block.super }}
{% endblock %}

{% block footer %}
<div id="footer" class="submit-row">
    <a href="https://github.com/jedie/django-fritzconnection">github.com/jedie/django-fritzconnection</a>
    |
    <a href="https://github.com/kbr/fritzconnection">github.com/kbr/fritzconnection</a>
</div>
{% endblock %}